==> openshift-model-config-6.8.0-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class FeatureGateSpecFluent<A extends FeatureGateSpecFluent<A>> extends BaseFluent<A>{
  public FeatureGateSpecFluent() {
  }
  public FeatureGateSpecFluent(FeatureGateSpec instance) {
    instance = (instance != null ? instance : new FeatureGateSpec());

    if (instance != null) {
      this.withCustomNoUpgrade(instance.getCustomNoUpgrade());
      this.withFeatureSet(instance.getFeatureSet());
      this.withCustomNoUpgrade(instance.getCustomNoUpgrade());
      this.withFeatureSet(instance.getFeatureSet());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private CustomFeatureGatesBuilder customNoUpgrade;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  public CustomFeatureGates buildCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  public A withCustomNoUpgrade(CustomFeatureGates customNoUpgrade) {
    _visitables.get("customNoUpgrade").remove(this.customNoUpgrade);
    if (customNoUpgrade!=null){ this.customNoUpgrade= new CustomFeatureGatesBuilder(customNoUpgrade); _visitables.get("customNoUpgrade").add(this.customNoUpgrade);} else { this.customNoUpgrade = null; _visitables.get("customNoUpgrade").remove(this.customNoUpgrade); } return (A) this;
  }
  public boolean hasCustomNoUpgrade() {
    return this.customNoUpgrade != null;
  }
  public CustomNoUpgradeNested<A> withNewCustomNoUpgrade() {
    return new CustomNoUpgradeNested(null);
  }
  public CustomNoUpgradeNested<A> withNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return new CustomNoUpgradeNested(item);
  }
  public CustomNoUpgradeNested<A> editCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(null));
  }
  public CustomNoUpgradeNested<A> editOrNewCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(new CustomFeatureGatesBuilder().build()));
  }
  public CustomNoUpgradeNested<A> editOrNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(item));
  }
  public String getFeatureSet() {
    return this.featureSet;
  }
  public A withFeatureSet(String featureSet) {
    this.featureSet=featureSet; return (A) this;
  }
  public boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSpecFluent that = (FeatureGateSpecFluent) o;
    if (!java.util.Objects.equals(customNoUpgrade, that.customNoUpgrade)) return false;

    if (!java.util.Objects.equals(featureSet, that.featureSet)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(customNoUpgrade,  featureSet,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (customNoUpgrade != null) { sb.append("customNoUpgrade:"); sb.append(customNoUpgrade + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNoUpgradeNested<N> extends CustomFeatureGatesFluent<CustomNoUpgradeNested<N>> implements Nested<N>{
    CustomNoUpgradeNested(CustomFeatureGates item) {
      this.builder = new CustomFeatureGatesBuilder(this, item);
    }
    CustomFeatureGatesBuilder builder;
    public N and() {
      return (N) FeatureGateSpecFluent.this.withCustomNoUpgrade(builder.build());
    }
    public N endCustomNoUpgrade() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.9.0-sources.jar: io/fabric8/openshift/api/model/config/v1/FeatureGateSpecFluent.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.util.Map;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class FeatureGateSpecFluent<A extends FeatureGateSpecFluent<A>> extends BaseFluent<A>{
  public FeatureGateSpecFluent() {
  }
  
  public FeatureGateSpecFluent(FeatureGateSpec instance) {
    this.copyInstance(instance);
  }
  private CustomFeatureGatesBuilder customNoUpgrade;
  private String featureSet;
  private Map<String,Object> additionalProperties;
  
  protected void copyInstance(FeatureGateSpec instance) {
    instance = (instance != null ? instance : new FeatureGateSpec());
  
    if (instance != null) {
        this.withCustomNoUpgrade(instance.getCustomNoUpgrade());
        this.withFeatureSet(instance.getFeatureSet());
        this.withCustomNoUpgrade(instance.getCustomNoUpgrade());
        this.withFeatureSet(instance.getFeatureSet());
        this.withAdditionalProperties(instance.getAdditionalProperties());
      }
  }
  
  public CustomFeatureGates buildCustomNoUpgrade() {
    return this.customNoUpgrade!=null ?this.customNoUpgrade.build():null;
  }
  
  public A withCustomNoUpgrade(CustomFeatureGates customNoUpgrade) {
    _visitables.get("customNoUpgrade").remove(this.customNoUpgrade);
    if (customNoUpgrade!=null){ this.customNoUpgrade= new CustomFeatureGatesBuilder(customNoUpgrade); _visitables.get("customNoUpgrade").add(this.customNoUpgrade);} else { this.customNoUpgrade = null; _visitables.get("customNoUpgrade").remove(this.customNoUpgrade); } return (A) this;
  }
  
  public boolean hasCustomNoUpgrade() {
    return this.customNoUpgrade != null;
  }
  
  public CustomNoUpgradeNested<A> withNewCustomNoUpgrade() {
    return new CustomNoUpgradeNested(null);
  }
  
  public CustomNoUpgradeNested<A> withNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return new CustomNoUpgradeNested(item);
  }
  
  public CustomNoUpgradeNested<A> editCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(null));
  }
  
  public CustomNoUpgradeNested<A> editOrNewCustomNoUpgrade() {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(new CustomFeatureGatesBuilder().build()));
  }
  
  public CustomNoUpgradeNested<A> editOrNewCustomNoUpgradeLike(CustomFeatureGates item) {
    return withNewCustomNoUpgradeLike(java.util.Optional.ofNullable(buildCustomNoUpgrade()).orElse(item));
  }
  
  public String getFeatureSet() {
    return this.featureSet;
  }
  
  public A withFeatureSet(String featureSet) {
    this.featureSet=featureSet; return (A) this;
  }
  
  public boolean hasFeatureSet() {
    return this.featureSet != null;
  }
  
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  
  public boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    FeatureGateSpecFluent that = (FeatureGateSpecFluent) o;
    if (!java.util.Objects.equals(customNoUpgrade, that.customNoUpgrade)) return false;
  
    if (!java.util.Objects.equals(featureSet, that.featureSet)) return false;
  
    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(customNoUpgrade,  featureSet,  additionalProperties,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (customNoUpgrade != null) { sb.append("customNoUpgrade:"); sb.append(customNoUpgrade + ","); }
    if (featureSet != null) { sb.append("featureSet:"); sb.append(featureSet + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  public class CustomNoUpgradeNested<N> extends CustomFeatureGatesFluent<CustomNoUpgradeNested<N>> implements Nested<N>{
    CustomNoUpgradeNested(CustomFeatureGates item) {
      this.builder = new CustomFeatureGatesBuilder(this, item);
    }
    CustomFeatureGatesBuilder builder;
    
    public N and() {
      return (N) FeatureGateSpecFluent.this.withCustomNoUpgrade(builder.build());
    }
    
    public N endCustomNoUpgrade() {
      return and();
    }
    
  
  }

}
